/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

/**
 * <b>Tobago Framework Component Tag Library 4.6.0 -
 * (C) Copyright 2005-2022 The Apache Software Foundation</b>
 */
@org.apache.myfaces.tobago.apt.annotation.Taglib(
    shortName = "tc",
    uri = "http://myfaces.apache.org/tobago/component",
    listener = {
        "org.apache.myfaces.tobago.webapp.TobagoServletContextListener",
        "org.apache.myfaces.tobago.webapp.SecretSessionListener"},
    name = "tobago",
    displayName = "Tobago Components 4.6.0")

package org.apache.myfaces.tobago.internal.taglib.component;
